@@ -94,7 +94,8 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 
 - (void)setupContentViewWithContentInset:(BOOL)setInset
 {
-    CGRect viewDimensions = [UIScreen mainScreen].bounds;
+    VLCAppDelegate *appDelegate = [UIApplication sharedApplication].delegate;
+    CGRect viewDimensions = appDelegate.window.bounds;
     UIView *contentView = [[UIView alloc] initWithFrame:viewDimensions];
     contentView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
     contentView.backgroundColor = [UIColor VLCDarkBackgroundColor];
@@ -111,6 +112,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
             _tableView.indicatorStyle = UIScrollViewIndicatorStyleWhite;
             _tableView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
         }
+        _tableView.frame = viewDimensions;
         [contentView addSubview:_tableView];
         [_tableView reloadData];
     } else {
@@ -131,6 +133,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
             else
                 [_collectionView registerNib:[UINib nibWithNibName:@"VLCPlaylistCollectionViewCell" bundle:nil] forCellWithReuseIdentifier:@"PlaylistCell"];
         }
+        _collectionView.frame = viewDimensions;
         [contentView addSubview:_collectionView];
         [_collectionView reloadData];
     }
@@ -334,6 +337,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
             for (MLFile *file in iterFiles)
                 [self _deleteMediaObject:file];
         }
+        [[MLMediaLibrary sharedMediaLibrary] removeObject: album];
         // delete all episodes from a show
     } else if ([managedObject isKindOfClass:[MLShow class]]) {
         MLShow *show = managedObject;
@@ -345,6 +349,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
             for (MLFile *file in iterFiles)
                 [self _deleteMediaObject:file];
         }
+        [[MLMediaLibrary sharedMediaLibrary] removeObject: show];
         // delete all files from an episode
     } else if ([managedObject isKindOfClass:[MLShowEpisode class]]) {
         MLShowEpisode *episode = managedObject;
@@ -353,6 +358,7 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
         for (MLFile *file in iterFiles)
             [self _deleteMediaObject:file];
         // delete all files from a track
+        [[MLMediaLibrary sharedMediaLibrary] removeObject: episode];
     } else if ([managedObject isKindOfClass:[MLAlbumTrack class]]) {
         MLAlbumTrack *track = managedObject;
         NSSet *iterFiles = [NSSet setWithSet:track.files];
@@ -1023,11 +1029,13 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
             NSNumber *folderTrackNumber = [NSNumber numberWithInt:(int)[label files].count - 1];
             file.folderTrackNumber = folderTrackNumber;
 
+            id item;
             @synchronized(self) {
                 [_foundMedia removeObjectAtIndex:folderIndex];
                 [_foundMedia insertObject:label atIndex:folderIndex];
+
+                item = _foundMedia[((NSIndexPath *)_indexPaths[0]).item];
             }
-            id item = _foundMedia[((NSIndexPath *)_indexPaths[0]).item];
             if (![item isKindOfClass:[MLFile class]])
                 return;
 
